Module single

Module single 

This module is when witnesses are single field elements and DLs are of form P_1 = g^{x_1}, P_2 = g^{x_2}, …

Structs

Hom

Functions

create_homomorphisms
Create a homomorphism for each commitment
create_new_witnesses
The new witnesses are referred as Y in the paper
create_new_witnesses_and_their_commitment
Create the new witnesses and commit to them in a single commitment from the given witnesses and their individual commitments