pub struct Response<G: AffineRepr> {
pub z_prime_0: G::ScalarField,
pub z_prime_1: G::ScalarField,
pub A: Vec<G>,
pub B: Vec<G>,
}Fields
z_prime_0: G::ScalarFieldz_prime_1: G::ScalarFieldA: Vec<G>B: Vec<G>Implementations
Sourceimpl<G> Response<G>where
G: AffineRepr,
impl<G> Response<G>where
G: AffineRepr,
Sourcepub fn is_valid_recursive<D: Digest, L: LinearForm<G::ScalarField>>(
&self,
g: &[G],
h: &G,
k: &G,
P: &G,
y: &G::ScalarField,
linear_form: &L,
A_hat: &G,
t: &G::ScalarField,
c_0: &G::ScalarField,
c_1: &G::ScalarField,
) -> Result<(), CompSigmaError>
pub fn is_valid_recursive<D: Digest, L: LinearForm<G::ScalarField>>( &self, g: &[G], h: &G, k: &G, P: &G, y: &G::ScalarField, linear_form: &L, A_hat: &G, t: &G::ScalarField, c_0: &G::ScalarField, c_1: &G::ScalarField, ) -> Result<(), CompSigmaError>
Validate the proof of knowledge in the recursive manner where the size of the various
vectors is reduced to half in each iteration. This execution is similar to the prover’s.
A naive and thus slower implementation than is_valid
Sourcepub fn is_valid<D: Digest, L: LinearForm<G::ScalarField>>(
&self,
g: &[G],
h: &G,
k: &G,
P: &G,
y: &G::ScalarField,
linear_form: &L,
A_hat: &G,
t: &G::ScalarField,
c_0: &G::ScalarField,
c_1: &G::ScalarField,
) -> Result<(), CompSigmaError>
pub fn is_valid<D: Digest, L: LinearForm<G::ScalarField>>( &self, g: &[G], h: &G, k: &G, P: &G, y: &G::ScalarField, linear_form: &L, A_hat: &G, t: &G::ScalarField, c_0: &G::ScalarField, c_1: &G::ScalarField, ) -> Result<(), CompSigmaError>
Validate the proof of knowledge in the non-recursive manner. This will delay scalar multiplications
till the end similar to whats described in the Bulletproofs paper, thus is faster than the recursive
version above. The key idea is that the verifier knows both A and B at the start and thus he knows
all the immediate challenges c also at the start. Thus the verifier can create the final g’ and Q
in a single multi-scalar multiplication
pub fn recursively_validate_compressed<D: Digest, L: LinearForm<G::ScalarField>>( &self, Q: G::Group, g_hat: Vec<G>, L_tilde: L, k: &G, ) -> Result<(), CompSigmaError>
pub fn validate_compressed<D: Digest, L: LinearForm<G::ScalarField>>( &self, Q: G::Group, g_hat: Vec<G>, L_tilde: L, k: &G, ) -> Result<(), CompSigmaError>