pub struct Hom<G: AffineRepr>(pub Vec<G>);Tuple Fields
0: Vec<G>First n-k elements for multiples of P_i and next n for g. This holds the vector of
bases such that the inner product of this vector and vector Y given P_i
Implementations
Sourceimpl<G: AffineRepr> Hom<G>
impl<G: AffineRepr> Hom<G>
Sourcepub fn new(
g: G,
P: G,
k: usize,
n: usize,
i: usize,
) -> Result<Self, CompSigmaError>
pub fn new( g: G, P: G, k: usize, n: usize, i: usize, ) -> Result<Self, CompSigmaError>
For k known openings of n total commitments, the homomorphism for the commitment at index i is
g * t_i + P_i * -\sum_{j in 1..n-k}(a_j*i^j)
For g * t_i, the bases will be a vector [0, 0, ..., g, 0, ..., 0] of size n with g at index i and rest as 0
For P_i * \sum_{j in 1..n-k}(a_j*i^j), its equal to P_i * -a_1 * i + P_2 * -a_2 * i^2 + ... + P_i * -a_{n-k} * i^{n-k}
which is equal to (P_i * -i) * a_1 + (P_i * -i^2) * a_2 + ... + (P_i * -i^{n-k}) * a_{n-k}. Thus the bases for it
can be written as vector [(P_i * -i), (P_i * -i^2), ..., (P_i * -i^{n-k})] of size n-k.
Thus the final bases are [(P_i * -i), (P_i * -i^2), ..., (P_i * -i^{n-k}), 0, 0, ..., g, 0, ..., 0] of size 2*n-k